<?php
/**
 * WooCommerce Mollie
 *
 * This source file is subject to the GNU General Public License v3.0
 * that is bundled with this package in the file license.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@skyverge.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade WooCommerce Mollie to newer
 * versions in the future. If you wish to customize WooCommerce Mollie for your
 * needs please refer to http://docs.woocommerce.com/document/mollie-ideal/
 *
 * @author    SkyVerge
 * @copyright Copyright (c) 2011-2020, SkyVerge, Inc. (info@skyverge.com)
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License v3.0
 */

namespace SkyVerge\WooCommerce\Mollie;

defined( 'ABSPATH' ) or exit;

use SkyVerge\WooCommerce\PluginFramework\v5_5_0 as Framework;

/**
 * Lifecycle handler.
 *
 * @since 2.13.0
 *
 * @method \WC_Mollie get_plugin()
 */
class Lifecycle extends Framework\Plugin\Lifecycle {


	/**
	 * Lifecycle constructor.
	 *
	 * @since 2.13.1
	 *
	 * @param \WC_Mollie $plugin
	 */
	public function __construct( $plugin ) {

		parent::__construct( $plugin );

		$this->upgrade_versions = [
			'2.0',
			'2.2.1',
			'2.12.2',
		];
	}


	/**
	 * Performs initial installation routines.
	 *
	 * @since 2.13.0
	 */
	protected function install() {

		// there was no database version prior to 2.0, so if we have settings on install then it means we're updating from 1.7
		if ( $this->get_plugin()->get_gateway_settings( $this->get_plugin()->get_id() ) ) {

			$this->upgrade( '1.7' );
			return;
		}

		// for a fresh install, mark the update-account-settings message as dismissed because it will never be shown to the admin anyways
		$this->get_plugin()->get_admin_notice_handler()->dismiss_notice( 'update-account-settings' );
	}


	/**
	 * Updates to v2.0
	 *
	 * @since 2.13.1
	 */
	protected function upgrade_to_2_0() {

		$settings = $this->get_plugin()->get_gateway_settings( $this->get_plugin()->get_id() );

		// base the current environment on the old testmode setting
		$settings['environment'] = isset( $settings['testmode'] ) && 'yes' === $settings['testmode'] ? 'test' : 'production';

		unset( $settings['testmode'] );

		update_option( $this->get_plugin()->get_gateway_settings_name( $this->get_plugin()->get_id() ), $settings );
	}


	/**
	 * Updates to v2.2.1
	 *
	 * @since 2.13.1
	 */
	protected function upgrade_to_2_2_1() {

		$settings = $this->get_plugin()->get_gateway_settings( $this->get_plugin()->get_id() );

		if ( ! isset( $settings['title'] ) ) {
			$settings['title'] = '{method title}';
		}

		if ( ! isset( $settings['description'] ) ) {
			$settings['description'] = 'Pay securely using {method title}';
		}

		update_option( $this->get_plugin()->get_gateway_settings_name( $this->get_plugin()->get_id() ), $settings );
	}


	/**
	 * Updates to v2.12.2
	 *
	 * @since 2.13.1
	 */
	protected function upgrade_to_2_12_2() {

		$settings = $this->get_plugin()->get_gateway_settings( $this->get_plugin()->get_id() );

		unset( $settings['test_webhook_configured'], $settings['webhook_configured'] );

		update_option( $this->get_plugin()->get_gateway_settings_name( $this->get_plugin()->get_id() ), $settings );
	}


}
